Index: trunk/SophyaLib/NTools/generalfit.cc
===================================================================
--- trunk/SophyaLib/NTools/generalfit.cc	(revision 926)
+++ trunk/SophyaLib/NTools/generalfit.cc	(revision 938)
@@ -797,5 +797,5 @@
   Retourne les valeurs des parametres dans un vecteur.
 */
-Vector GeneralFit::GetParm()
+TVector<r_8> GeneralFit::GetParm()
 {
 return Param;
@@ -1003,11 +1003,11 @@
 {
  volatile double oldChi2;
- Matrix COVAR(mNPar,mNPar);
- Vector DA(mNPar);
- Vector dparam(mNPar);
- Vector paramTry(mNPar);
- Vector param_tr(mNPar);
- Vector paramTry_tr(mNPar);
- Vector step_tr(mNPar);
+ TMatrix<r_8> COVAR(mNPar,mNPar);
+ TVector<r_8> DA(mNPar);
+ TVector<r_8> dparam(mNPar);
+ TVector<r_8> paramTry(mNPar);
+ TVector<r_8> param_tr(mNPar);
+ TVector<r_8> paramTry_tr(mNPar);
+ TVector<r_8> step_tr(mNPar);
  nStop = nStopL = nStep = 0;
  Chi2 = oldChi2 = 0.;
@@ -1418,5 +1418,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::write_in_step(double ci2,Vector& par)
+void GeneralFit::write_in_step(double ci2,TVector<r_8>& par)
 {
 if(FileStep==NULL) return;
@@ -1427,11 +1427,11 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::TryFunc(Vector& par,Vector& par_tr)
+void GeneralFit::TryFunc(TVector<r_8>& par,TVector<r_8>& par_tr)
 {
   BETA_Try = 0;
   ATGA_Try = 0;
   Chi2  = 0;
-  Vector deriv(mNPar);
-  Vector derivtr(mNPar);
+  TVector<r_8> deriv(mNPar);
+  TVector<r_8> derivtr(mNPar);
   double result;
 
@@ -1467,5 +1467,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::TryXi2(Vector& par,Vector& par_tr)
+void GeneralFit::TryXi2(TVector<r_8>& par,TVector<r_8>& par_tr)
 {
   double c, *parloc;
@@ -1575,7 +1575,7 @@
 
 //////////////////////////////////////////////////////////////////////
-Vector GeneralFit::p_vers_tr(Vector const& p)
-{
- Vector tr(p);
+TVector<r_8> GeneralFit::p_vers_tr(TVector<r_8> const& p)
+{
+ TVector<r_8> tr(p);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1586,5 +1586,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::p_vers_tr(Vector const& p,Vector& tr)
+void GeneralFit::p_vers_tr(TVector<r_8> const& p,TVector<r_8>& tr)
 {
  for(int i=0;i<mNPar;i++) {
@@ -1610,7 +1610,7 @@
 
 //////////////////////////////////////////////////////////////////////
-Vector GeneralFit::tr_vers_p(Vector const& tr)
-{
- Vector p(tr);
+TVector<r_8> GeneralFit::tr_vers_p(TVector<r_8> const& tr)
+{
+ TVector<r_8> p(tr);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1621,5 +1621,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::tr_vers_p(Vector const& tr,Vector& p)
+void GeneralFit::tr_vers_p(TVector<r_8> const& tr,TVector<r_8>& p)
 {
  for(int i=0;i<mNPar;i++) {
@@ -1646,7 +1646,7 @@
 
 //////////////////////////////////////////////////////////////////////
-Vector GeneralFit::dp_vers_dtr(Vector const& dp,Vector const& tr)
-{
- Vector dtr(dp);
+TVector<r_8> GeneralFit::dp_vers_dtr(TVector<r_8> const& dp,TVector<r_8> const& tr)
+{
+ TVector<r_8> dtr(dp);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1657,5 +1657,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::dp_vers_dtr(Vector const& dp,Vector const& tr,Vector& dtr)
+void GeneralFit::dp_vers_dtr(TVector<r_8> const& dp,TVector<r_8> const& tr,TVector<r_8>& dtr)
 {
  for(int i=0;i<mNPar;i++) {
@@ -1682,7 +1682,7 @@
 
 //////////////////////////////////////////////////////////////////////
-Vector GeneralFit::dtr_vers_dp(Vector const& dtr,Vector const& tr)
-{
- Vector dp(dtr);
+TVector<r_8> GeneralFit::dtr_vers_dp(TVector<r_8> const& dtr,TVector<r_8> const& tr)
+{
+ TVector<r_8> dp(dtr);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1694,5 +1694,5 @@
 //////////////////////////////////////////////////////////////////////
 // inline fonction pour aller + vite dans le try()
 //void GeneralFit::dtr_vers_dp(Vector const& dtr,Vector const& tr,Vector& dp)
 
 //////////////////////////////////////////////////////////////////////
@@ -1706,5 +1706,5 @@
   \endverbatim
 */
-int GeneralFit::put_in_limits_for_deriv(Vector const& p,Vector& dp,double dist)
+int GeneralFit::put_in_limits_for_deriv(TVector<r_8> const& p,TVector<r_8>& dp,double dist)
 {
  int nchanged = 0;
@@ -1694,5 +1694,5 @@
 //////////////////////////////////////////////////////////////////////
 // inline fonction pour aller + vite dans le try()
-//void GeneralFit::dtr_vers_dp(Vector const& dtr,Vector const& tr,Vector& dp)
+//void GeneralFit::dtr_vers_dp(TVector<r_8> const& dtr,TVector<r_8> const& tr,TVector<r_8>& dp)
 
 //////////////////////////////////////////////////////////////////////
